@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v0.3.2");
+use version; our $VERSION = version->declare("v0.4.0");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -128,6 +128,15 @@ Grab abstract information from the file contains pod.
 
 Grab authors information from the file contains pod.
 
+=item allow_pure_perl
+
+    allow_pure_perl=1
+
+A bool indicating the module is still functional without its XS parts.  When an XS module is build
+with C<--pureperl_only>, it will otherwise fail.
+
+It affects to L<Module::Build> 0.4005+ only.
+
 =item no_github_issues
 
     no_github_issues=true
@@ -143,6 +152,19 @@ Minilla sets META.json's no_index as C<< directory => ['t', 'xt', 'inc', 'share'
 by default. But if you want to change them, you can set this section variable. If this section is set,
 specified variables are only used, in fact default settings are not merged.
 
+=item script_files
+
+    script_files = ['bin/foo', 'script/*']
+
+Minilla sets install script files as C<< ['script/*', 'bin/*'] >> by default.
+
+=item build.build_class
+
+Specify a custom Module::Build subclass.
+
+    [build]
+    build_class = builder::MyBuilder
+
 =back
 
 =head1 FAQ
